# The software in this package is distributed under the GNU General
# Public License version 2 (with a special exception described below).
#
# A copy of GNU General Public License (GPL) is included in this distribution,
# in the file COPYING.GPL.
#
# As a special exception, if other files instantiate templates or use macros
# or inline functions from this file, or you compile this file and link it
# with other works to produce a work based on this file, this file
# does not by itself cause the resulting work to be covered
# by the GNU General Public License.
#
# However the source code for this file must still be made available
# in accordance with section (3) of the GNU General Public License.
#
# This exception does not invalidate any other reasons why a work based
# on this file might be covered by the GNU General Public License.
#
# Copyright (c) 2016-2018 Intra2net AG <info@intra2net.com>

from .build_cnfvar import BuildCnfVar
"""Class to configure the proxy antivirus cnfvars on the fly"""


class ConfigureProxyAntivirus(BuildCnfVar):
    def __init__(self, enabled='1', line_no=1):
        BuildCnfVar.__init__(self, 'VIRSCAN_PROXY_ENABLE',
                             0, enabled, line_no)

    def automatic_unblock(self, block_minutes):
        line_no = self.update_cnf('VIRSCAN_PROXY_AUTOMATIC_UNBLOCK', 0, block_minutes)
        self.mark_as_own_parent(line_no)
        return self

    def debug_log(self, enabled='1'):
        line_no = self.update_cnf('VIRSCAN_PROXY_DEBUG_LOG', 0, enabled)
        self.mark_as_own_parent(line_no)
        return self

    def add_pass_site(self, url):
        sites_parent = self.update_cnf('VIRSCAN_PROXY_PASS_SITES', 0, '')
        self.mark_as_own_parent(sites_parent)

        self.add_cnf('VIRSCAN_PROXY_PASS_SITES_ADDR', -1, url, sites_parent)
        return self

    def clear_pass_sites(self):
        self.del_cnf('VIRSCAN_PROXY_PASS_SITES_ADDR')
        self.del_cnf('VIRSCAN_PROXY_PASS_SITES')
        return self

    def warn_admin(self, enabled='1'):
        line_no = self.update_cnf('VIRSCAN_PROXY_WARN_ADMIN', 0, enabled)
        self.mark_as_own_parent(line_no)
        return self
